@@ -1,5 +1,5 @@
 import pandas as pd
-def topsis(df,weights,impacts)
+def topsis(df,weights,impacts):
     vjp=[]
     vjn=[]
     for i in range(1,df.shape[1]):
